==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/hr-HR/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Ovaj korisnik se može prijaviti',
    'activated_disabled_help_text' => 'Ne možete mijenjati status aktivacije za svoj vlastiti račun.',
    'assets_user'       => 'Imovina dodijeljena za: ime',
    'bulk_update_warn'	=> 'Namjeravate uređivati ​​svojstva korisnika: user_count. Imajte na umu da ne možete mijenjati vlastite korisničke atribute pomoću ovog obrasca i morati sami uređivati ​​vlastiti korisnik.',
    'bulk_update_help'	=> 'Ovaj vam obrazac omogućuje ažuriranje više korisnika odjednom. Popunite polja koja su vam potrebna za promjenu. Sva polja koja su ostala prazna ostat će nepromijenjena.',
    'current_assets'    => 'Aktiva koji su trenutačno prijavljeni ovom korisniku',
    'clone'             => 'Korisnik klona',
    'contact_user'      => 'Ime kontakta',
    'edit'              => 'Uređivanje korisnika',
    'filetype_info'     => 'Dopuštene vrste datoteka su png, gif, jpg, jpeg, doc, docx, pdf, txt, zip i rar.',
    'history_user'      => 'Povijest za: ime',
    'info'				=> 'Informacije',
    'restore_user'		=> 'Kliknite ovdje da biste ih vratili.',
    'last_login'        => 'Zadnja prijava',
    'ldap_config_text'  => 'Postavke LDAP konfiguracije mogu se pronaći u Administrator> Postavke. Odabrana lokacija (opcionalno) bit će postavljena za sve uvezene korisnike.',
    'print_assigned'    => 'Ispiši sve dodijeljeno',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Softver je provjeren na: ime',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Prikaži korisnika: ime',
    'usercsv'           => 'CSV datoteku',
    'two_factor_admin_optin_help' => 'Vaše trenutačne postavke administracije omogućuju selektivnu provedbu autentikacije dvogritera.',
    'two_factor_enrolled' => '2FA uređaj upisan',
    'two_factor_active'   => '2FA aktivno',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/hr-HR/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Ovaj korisnik se može prijaviti',
    'activated_disabled_help_text' => 'Ne možete mijenjati status aktivacije za svoj vlastiti račun.',
    'assets_user'       => 'Imovina dodijeljena za: ime',
    'bulk_update_warn'	=> 'Namjeravate uređivati ​​svojstva korisnika: user_count. Imajte na umu da ne možete mijenjati vlastite korisničke atribute pomoću ovog obrasca i morati sami uređivati ​​vlastiti korisnik.',
    'bulk_update_help'	=> 'Ovaj vam obrazac omogućuje ažuriranje više korisnika odjednom. Popunite polja koja su vam potrebna za promjenu. Sva polja koja su ostala prazna ostat će nepromijenjena.',
    'current_assets'    => 'Aktiva koji su trenutačno prijavljeni ovom korisniku',
    'clone'             => 'Korisnik klona',
    'contact_user'      => 'Ime kontakta',
    'edit'              => 'Uređivanje korisnika',
    'filetype_info'     => 'Dopuštene vrste datoteka su png, gif, jpg, jpeg, doc, docx, pdf, txt, zip i rar.',
    'history_user'      => 'Povijest za: ime',
    'info'				=> 'Informacije',
    'restore_user'		=> 'Kliknite ovdje da biste ih vratili.',
    'last_login'        => 'Zadnja prijava',
    'ldap_config_text'  => 'Postavke LDAP konfiguracije mogu se pronaći u Administrator> Postavke. Odabrana lokacija (opcionalno) bit će postavljena za sve uvezene korisnike.',
    'print_assigned'    => 'Ispiši sve dodijeljeno',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Softver je provjeren na: ime',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Prikaži korisnika: ime',
    'usercsv'           => 'CSV datoteku',
    'two_factor_admin_optin_help' => 'Vaše trenutačne postavke administracije omogućuju selektivnu provedbu autentikacije dvogritera.',
    'two_factor_enrolled' => '2FA uređaj upisan',
    'two_factor_active'   => '2FA aktivno',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];
